==> haskell-status-notifier-item-0.3.1.0-313-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-w1btcKV7yH18xB1IollUE
key:                  status-notifier-item-0.3.1.0-w1btcKV7yH18xB1IollUE
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  421d7a50b72a4c76d439e421ae426151
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-w1btcKV7yH18xB1IollUE
depends:
    base-4.18.2.1 byte-order-0.1.3.1-1jbsg3vHp0VBUn11aq8Keh
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-DefKISIAw4mGPY9DKJ71qg
    containers-0.6.7 dbus-1.3.3-KJsquVyFPuP5xKdFIZC0f4
    filepath-1.4.300.1 hslogger-1.3.2.0-FPaqfjIzB5mGOypIyafcGO
    lens-5.3.3-J3Ejqn7P12hA3GpyJcCxW8 template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-status-notifier-item-0.3.1.0-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-status-notifier-item.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 status-notifier-item
version:              0.3.1.0
visibility:           public
id:                   status-notifier-item-0.3.1.0-2AslohjBm0m3afNAIcBwy9
key:                  status-notifier-item-0.3.1.0-2AslohjBm0m3afNAIcBwy9
license:              BSD-3-Clause
copyright:            2018 Ivan Malison
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/IvanMalison/status-notifier-item#readme
synopsis:
    A wrapper over the StatusNotifierItem/libappindicator dbus specification

description:
    Please see the README on Github at <https://github.com/IvanMalison/status-notifier-item#readme>

category:             Desktop
abi:                  841af056ba77e6a130b39e9f8a22dbde
exposed:              True
exposed-modules:
    StatusNotifier.Host.Service StatusNotifier.Item.Client
    StatusNotifier.Item.Service StatusNotifier.TH StatusNotifier.Util
    StatusNotifier.Watcher.Client StatusNotifier.Watcher.Constants
    StatusNotifier.Watcher.Service StatusNotifier.Watcher.Signals

hidden-modules:       Paths_status_notifier_item
import-dirs:          /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/status-notifier-item-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-status-notifier-item
hs-libraries:         HSstatus-notifier-item-0.3.1.0-2AslohjBm0m3afNAIcBwy9
depends:
    base-4.18.2.1 byte-order-0.1.3.1-F4jzvmFb0oDGzdXQWovBRt
    bytestring-0.11.5.3
    bytestring-to-vector-0.3.0.1-DefKISIAw4mGPY9DKJ71qg
    containers-0.6.7 dbus-1.3.3-3PONqztD5YgKCjXAfJFvrC
    filepath-1.4.300.1 hslogger-1.3.2.0-FPaqfjIzB5mGOypIyafcGO
    lens-5.3.3-J3Ejqn7P12hA3GpyJcCxW8 template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:
    /usr/share/doc/haskell-status-notifier-item/html/status-notifier-item.haddock

haddock-html:         /usr/share/doc/haskell-status-notifier-item/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
